--- emacs20/wnn7egg-com.el.orig	2002-05-26 15:00:00 UTC
+++ emacs20/wnn7egg-com.el
@@ -73,6 +73,8 @@
 ;; Japanese
 
 (eval-and-compile
+  (if (string< emacs-version "22.0") ;; Emacs 22 or lesser.
+      (progn
 (define-ccl-program ccl-decode-fixed-euc-jp
   `(2
     ((r2 = ,(charset-id 'japanese-jisx0208))
@@ -125,12 +127,31 @@
       (read r0)
       (repeat)))))
 )
+;; From Handa-san. [mule-ja : No.09414]
+(define-charset 'fixed-euc-jp
+  "Fixed EUC Japanese"
+  :dimension 2
+  :superset '(ascii
+	      (katakana-jisx0201 . #x80)
+	      (japanese-jisx0208 . #x8080)
+	      (japanese-jisx0212 . #x8000)))
 
-(if (not (coding-system-p 'fixed-euc-jp))
-    (make-coding-system 'fixed-euc-jp 4 ?W 
-		"Coding System for fixed EUC Japanese"
-		(cons ccl-decode-fixed-euc-jp ccl-encode-fixed-euc-jp)))
+(define-coding-system 'fixed-euc-jp
+  "Coding System for fixed EUC Japanese"
+  :mnemonic ?W
+  :coding-type 'charset
+  :charset-list '(fixed-euc-jp))
+))
 
+(if (and (string< emacs-version "22.0") ;; Emacs 22 or lesser.
+	 (not (coding-system-p 'fixed-euc-jp)))
+     (define-coding-system 'fixed-euc-jp "Coding System for fixed EUC Japanese"
+      :mnemonic ?W :coding-type 'charset
+      :charset-list '(fixed-euc-jp)))
+;    (make-coding-system 'fixed-euc-jp 4 ?W 
+;		"Coding System for fixed EUC Japanese"
+;		(cons ccl-decode-fixed-euc-jp ccl-encode-fixed-euc-jp)))
+
 ;; Binary data
 
 (eval-and-compile
@@ -152,20 +173,23 @@
       (write-read-repeat r0))))))
 
 (if (not (coding-system-p 'egg-binary))
-    (make-coding-system 'egg-binary 4 ?W "Coding System for binary data"
-		    (cons ccl-decode-egg-binary ccl-encode-egg-binary)))
+     (define-coding-system 'egg-binary "Coding System for binary data"
+      :mnemonic ?W :coding-type 'ccl :ccl-decoder ccl-decode-egg-binary
+      :ccl-encoder ccl-encode-egg-binary))
+;    (make-coding-system 'egg-binary 4 ?W "Coding System for binary data"
+;		    (cons ccl-decode-egg-binary ccl-encode-egg-binary)))
 
 
 (defun comm-format-u32c (uint32c)
-  (insert-char (logand (lsh (car uint32c) -8) 255) 1)
+  (insert-char (logand (ash (car uint32c) -8) 255) 1)
   (insert-char (logand (car uint32c) 255) 1)
-  (insert-char (logand (lsh (nth 1 uint32c) -8) 255) 1)
+  (insert-char (logand (ash (nth 1 uint32c) -8) 255) 1)
   (insert-char (logand (nth 1 uint32c) 255) 1))
 
 (defun comm-format-u32 (uint32)
-  (insert-char (logand (lsh uint32 -24) 255) 1)
-  (insert-char (logand (lsh uint32 -16) 255) 1)
-  (insert-char (logand (lsh uint32 -8) 255) 1)
+  (insert-char (logand (ash uint32 -24) 255) 1)
+  (insert-char (logand (ash uint32 -16) 255) 1)
+  (insert-char (logand (ash uint32 -8) 255) 1)
   (insert-char (logand uint32 255) 1))
 
 (defun comm-format-i32 (int32)
@@ -175,7 +199,7 @@
   (insert-char (logand int32 255) 1))
 
 (defun comm-format-u16 (uint16)
-  (insert-char (logand (lsh uint16 -8) 255) 1)
+  (insert-char (logand (ash uint16 -8) 255) 1)
   (insert-char (logand uint16 255) 1))
 
 (defun comm-format-u8 (uint8)
@@ -287,23 +311,29 @@ V: Fixed length string (0x00 terminated).  This takes 
 (defun comm-unpack-u32c ()
   (progn
     (comm-require-process-output 4)
-    (list (+ (lsh (comm-following+forward-char) 8)
+    (list (+ (ash (comm-following+forward-char) 8)
 	     (comm-following+forward-char))
-	  (+ (lsh (comm-following+forward-char) 8)
+	  (+ (ash (comm-following+forward-char) 8)
 	     (comm-following+forward-char)))))
 
 (defun comm-unpack-u32 ()
   (progn
     (comm-require-process-output 4)
-    (+ (lsh (comm-following+forward-char) 24)
-       (lsh (comm-following+forward-char) 16)
-       (lsh (comm-following+forward-char) 8)
-       (comm-following+forward-char))))
+    (if (= integer_width_29bit 1)
+    (+ (ash (comm-following+forward-char) 24)
+       (ash (comm-following+forward-char) 16)
+       (ash (comm-following+forward-char) 8)
+          (comm-following+forward-char))
+      ;; for 62bit width
+      (ash (ash (+ (ash (comm-following+forward-char) 24)
+                  (ash (comm-following+forward-char) 16)
+                  (ash (comm-following+forward-char) 8)
+                  (comm-following+forward-char)) 30) -30))))
 
 (defun comm-unpack-u16 ()
   (progn
     (comm-require-process-output 2)
-    (+ (lsh (comm-following+forward-char) 8)
+    (+ (ash (comm-following+forward-char) 8)
        (comm-following+forward-char))))
 
 (defun comm-unpack-u8 ()
@@ -335,7 +365,7 @@ V: Fixed length string (0x00 terminated).  This takes 
   (let ((start (point)))
     (while (not (search-forward "\377\377" nil 1))
       (comm-accept-process-output))
-    (string-as-unibyte
+     (string-as-unibyte
      (decode-coding-string (buffer-substring start (- (point) 2))
 			   'egg-binary))))
 
